#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/gvfs/1.6/gvfs-1.6.6.tar.bz2
#
# maintainer: (package seek a maintainers)
#

#------------------ Set Some Variables

soft='gvfs'
softversion='1.8.1'
arch="i486"
cpu="i686"
packageversion="72.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
PKG="/tmp/$package"

# ----------------- Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $PKG.tgz
rm -rf $PKG

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --disable-static \
  --enable-gtk-doc=no 

make -j2
make install DESTDIR=$PKG

find $PKG | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Documentation

install -d -m 755 -o root -g root $PKG/usr/doc/$soft-$softversion
install -m 644 -o root -g root AUTHORS ChangeLog COPYING INSTALL MAINTAINERS NEWS README README.commits TODO $PKG/usr/doc/$soft-$softversion

cd $buildir

# compile Glib schemas
/usr/bin/glib-compile-schemas --allow-any-name $PKG/usr/share/glib-2.0/schemas

mkdir -p $PKG/install
cat << "EODESC" > $PKG/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

    |-----handy-ruler--------------------------------------------------------|
gvfs: gvfs - is a userspace virtual filesystem
gvfs:
gvfs: gvfs is a userspace virtual filesystem where mount runs as a separate
gvfs: processes which you talk to via dbus. It also contains a gio module
gvfs: that seamlessly adds gvfs support to all applications using the gio
gvfs: API. It also supports exposing the gvfs mounts to non-gio applications
gvfs: using fuse.
gvfs:
gvfs:
gvfs:
gvfs:
EODESC


install -D -m 644 -o root -g root $buildir/build-$soft.sh $PKG/usr/src/$soft-$softversion/build-$soft.sh

# Packaging

cd $PKG
makepkg -l y -c n $PKG.txz

cd $buildir

